##########
References
##########

C11: `Compiegne et al. 2011, A&A, 525, 103
<https://ui.adsabs.harvard.edu/abs/2011A%26A...525A.103C>`_

CCM89: `Cardelli, Clayton, & Mathis 1989, ApJ, 345, 245
<https://ui.adsabs.harvard.edu/abs/1989ApJ...345..245C>`_

CT06: `Chiar & Tielens 2006, ApJ, 637 774
<https://ui.adsabs.harvard.edu/abs/2006ApJ...637..774C>`_

D03: `Draine 2003, ARA&A, 41, 241
<https://ui.adsabs.harvard.edu/abs/2003ARA%26A..41..241D>`_;
`Draine 2003, ApJ, 598, 1017
<https://ui.adsabs.harvard.edu/abs/2003ApJ...598.1017D>`_

D22: `Decleir et al. 2022, ApJ, 930, 15
<https://ui.adsabs.harvard.edu/abs/2022ApJ...930...15D>`_

DBP90: `Desert, Boulanger, & Puget 1990, A&A, 237, 215
<https://ui.adsabs.harvard.edu/abs/1990A%26A...237..215D>`_

F99: `Fitzpatrick 1999, PASP, 111, 63
<https://ui.adsabs.harvard.edu/abs/1999PASP..111...63F>`_

F04: `Fitzpatrick 2004, ASP Conf. Ser. 309, Astrophysics of Dust, 33
<https://ui.adsabs.harvard.edu/abs/2004ASPC..309...33F>`_

FM90: `Fitzpatrick & Massa 1990, ApJS, 72, 163
<https://ui.adsabs.harvard.edu/abs/1990ApJS...72..163F>`_

FM07: `Fitzpatrick & Massa 2007, ApJ, 663, 320
<https://ui.adsabs.harvard.edu/abs/2007ApJ...663..320F>`_

F19: `Fitzpatrick, Massa, Gordon, et al. 2019, ApJ, 886, 108
<https://ui.adsabs.harvard.edu/abs/2019ApJ...886..108F>`_

F11: `Fritz et al. 2011, ApJ, 737, 73
<https://ui.adsabs.harvard.edu/abs/2011ApJ...737...73F>`_

G03: `Gordon et al. 2003, ApJ, 594, 279
<https://ui.adsabs.harvard.edu/abs/2003ApJ...594..279G>`_

GCC09: `Gordon, Cartledge, & Clayton 2009, ApJ, 705, 1320
<https://ui.adsabs.harvard.edu/abs/2009ApJ...705.1320G>`_

G16: `Gordon et al. 2016, ApJ 826, 104
<https://ui.adsabs.harvard.edu/abs/2016ApJ...826..104G>`_

G21: `Gordon et al. 2021, ApJ, 916, 33
<https://ui.adsabs.harvard.edu/abs/2021ApJ...916...33G>`_

G23: `Gordon et al. 2023, ApJ, 950, 86
<https://ui.adsabs.harvard.edu/abs/2023ApJ...950...86G/abstract>`_

G24: Gordon et al. 2024, ApJ, in press

HD23: `Hensley & Draine 2023, ApJ, 948, 55
<https://ui.adsabs.harvard.edu/abs/2023ApJ...948...55H/abstract>`_

I05: `Indebetouw et al. 2005, ApJ, 619, 931
<https://ui.adsabs.harvard.edu/abs/2005ApJ...619..931I>`_

J13: `Jones et al. 2013, A&A, 558, 62
<https://ui.adsabs.harvard.edu/abs/2013A%26A...558A..62J>`_

KJY14: `Kohler, Jones, & Ysard 2014, A&A, 565, 9
<https://ui.adsabs.harvard.edu/abs/2014A%26A...565L...9K>`_

M14: `Maiz Apell\’aniz et al. 2014, A&A, 564, 63
<https://ui.adsabs.harvard.edu/abs/2014A%26A...564A..63M>`_

OD94: `O'Donnell 1994, 422, 1580
<https://ui.adsabs.harvard.edu/abs/1994ApJ...422..158O>`_

P92: `Pei 1992, ApJ, 395, 130
<https://ui.adsabs.harvard.edu/abs/1992ApJ...395..130P>`_

RL85: `Rieke & Lebofsky 1985, ApJ,288, 618
<https://ui.adsabs.harvard.edu/abs/1985ApJ...288..618R>`_

VCG04: `Valencic, Clayton, & Gordon 2014, 616, 912
<https://ui.adsabs.harvard.edu/abs/2004ApJ...616..912V>`_

WG01: `Weingartner & Draine 2001, ApJ, 548, 296
<https://ui.adsabs.harvard.edu/abs/2001ApJ...548..296W>`_

ZDA04: `Zubko, Dwek, & Arendt 2004, ApJS, 152, 211
<https://ui.adsabs.harvard.edu/abs/2004ApJS..152..211Z>`_

Naming Convention
=================

The names of models are use the paper where they were presented and are
based on the author last name initials and year published.
For papers with 3 or fewer authors, the initials of all the authors are used.
For papers with 4 or more authors, only the initial of the 1st authors is used.
